@@ -1438,9 +1438,11 @@ draw_arrow (GtkStyle *style,
 {
     eazel_theme_data *theme_data;
 
-    /*    printf ("not doing an arrow\n");
-
-    return;*/
+    /* FIXME GNOME2: bad hack added to make arrows draw large enough */
+    width = width + 6;
+    height = height + 6;
+    x = x - 3;
+    y = y - 3;
 
     g_return_if_fail (style != NULL);
     g_return_if_fail (window != NULL);
